\name{deco-package}
\alias{deco-package}
\alias{deco}
\docType{package}
\title{
DECO: DEcomposing heterogeneous Cohorts from Omic profiling.
}
\description{
DECO integrates a two-step methodology to find out outlier behavior of features which could determine a new subclass of samples. Thus, a subsampling method with LIMMA (Stratified Differential Analysis or \emph{RDA}) will be applied to a omic matrix data, previously normalized. After that, Non-Symmetrical Correspondence Analysis (\emph{NSCA}) will be computed on frequency matrix of differential events generated by subsampling.

The feature-sample relationships will define stratified profiles with statistical significance. Any new subclass defined could be associated to hidden phenotypic variables.
}
\details{
\tabular{ll}{
Package: \tab deco\cr
Type: \tab Package\cr
Version: \tab 0.99\cr
Date: \tab 2018-11-15\cr
License: \tab GPL 3.0\cr
}

}
\author{
Francisco Jose Campos Laborie, Jose Manuel Sanchez Santos and Javier De las Rivas.

Maintainer: Francisco Jose Campos Laborie <fjcamlab@usal.es>,
Cancer Research Centre (Salamanca) <jrivas@usal.es>
}
\references{
Campos-Laborie, FJ et al. \bold{DECO: decompose heterogeneous population cohorts for patient stratification and discovery of sample biomarkers using omic data profiling.} (2018)

Scarfo, Irene et al. \bold{Identification of a new subclass of ALK negative ALCL expressing aberrant levels of ERBB4 transcripts.} \emph{Blood} (2015). \url{http://dx.doi.org/10.1182/blood-2014-12-614503}.
}
\keyword{ package }
\seealso{
\code{\link[deco]{decoRDA}}, \code{\link[deco]{decoNSCA}}, \code{\link[deco]{decoReport}}, \code{\link[limma]{voom}}
}
\examples{
#### ALCL EXAMPLE (Scarfo et al., 2015. Blood) ####
## Group-VS-group comparison

########################
# Loading example data #
########################
# Data from two subtypes (ALK+ and ALK-) of Anaplastic Large Cell Leukemia (ALCL).
data(ALCLdata)

## Classes vector to run a supervised analysis to compare both classes.
classes.ALCL <- colData(ALCL)[,"Alk.positivity"]
names(classes.ALCL) <- colnames(ALCL)

####################################
# Parallelization via BiocParallel #
####################################
# Non-parallel computing
bpparam <- SerialParam()

# Computing in shared memory
# all cores by deault
bpparam <- MulticoreParam()

#######################################################################
# RUNNING SUBSAMPLING OF DATA: BINARY design (two classes of samples) #
#######################################################################
# if annotation and rm.xy == TRUE, then
# library(Homo.sapiens)

# Not run as example
# sub.ma.3r.1K <- decoRDA(data = assay(ALCL), classes = classes.ALCL, q.val = 0.01,
#                rm.xy = TRUE, r = NULL, control = "pos", annot = FALSE, bpparam = bpparam,
#                id.type = "ENSEMBL", iterations = 10000, pack.db = "Homo.sapiens")


#########################################################################################
# RUNNING NSCA STEP: Looking for subclasses within a category/class of samples compared #
#########################################################################################
# Not run as example
# deco.results.ma <- decoNSCA(sub = sub.ma.3r.1K, v = 80, method = "ward.D", bpparam = bpparam,
#                        k.control = 3, k.case = 3, samp.perc = 0.05, rep.thr = 10)


# Phenotypical data from TCGA RNAseq samples.
colData(ALCL)

########################################################
# PDF report with feature-sample patterns or subgroups #
########################################################
## Generate PDF report with relevant information and several plots.

## Binary example (ALK+ vs ALK-) -not run as example-
# decoReport(deco.results.ma, sub.ma.3r.1K,
#           pdf.file = "report_example_microarray_binary.pdf",
#           info.sample = as.data.frame(colData(ALCL)[,8:10]),
#           cex.names = 0.3, print.annot = TRUE)

}
